﻿#pragma warning disable 1591
using System;
using System.Data;
using System.Linq;
using System.Linq.Expressions;
using System.Data.Common;
using System.Collections.Generic;
using Telerik.OpenAccess;
using Telerik.OpenAccess.Metadata;
using Telerik.OpenAccess.Data.Common;
using Telerik.OpenAccess.Metadata.Fluent;
using Telerik.OpenAccess.Metadata.Fluent.Advanced;
using DataAccessModel1;

namespace DataAccessModel1	
{
	public partial class FluentModel : OpenAccessContext, IEntitiesModelUnitOfWork
	{
		private static string connectionStringName = @"FlatInheritanceTestConnection";
			
		private static BackendConfiguration backend = GetBackendConfiguration();
				
		private static MetadataSource metadataSource = new FluentModelFluentMetadataSource();
		
		public FluentModel()
			:base(connectionStringName, backend, metadataSource)
		{ }
		
		public FluentModel(string connection)
			:base(connection, backend, metadataSource)
		{ }
		
		public FluentModel(BackendConfiguration backendConfiguration)
			:base(connectionStringName, backendConfiguration, metadataSource)
		{ }
			
		public FluentModel(string connection, MetadataSource metadataSource)
			:base(connection, backend, metadataSource)
		{ }
		
		public FluentModel(string connection, BackendConfiguration backendConfiguration, MetadataSource metadataSource)
			:base(connection, backendConfiguration, metadataSource)
		{ }
			
		public IQueryable<Address> Addresses 
		{
			get
			{
				return this.GetAll<Address>();
			}
		}
		
		public IQueryable<CustomerAddress> CustomerAddresses 
		{
			get
			{
				return this.GetAll<CustomerAddress>();
			}
		}
		
		public IQueryable<SupplierAddress> SupplierAddresses 
		{
			get
			{
				return this.GetAll<SupplierAddress>();
			}
		}
		
		public IQueryable<Customer> Customers 
		{
			get
			{
				return this.GetAll<Customer>();
			}
		}
		
		public IQueryable<Supplier> Suppliers 
		{
			get
			{
				return this.GetAll<Supplier>();
			}
		}
		
		public static BackendConfiguration GetBackendConfiguration()
		{
			BackendConfiguration backend = new BackendConfiguration();
			backend.Backend = "MsSql";
			backend.ProviderName = "System.Data.SqlClient";
			backend.Logging.MetricStoreSnapshotInterval = 0;
		
			CustomizeBackendConfiguration(ref backend);
		
			return backend;
		}
		
		/// <summary>
		/// Allows you to customize the BackendConfiguration of EntitiesModel.
		/// </summary>
		/// <param name="config">The BackendConfiguration of EntitiesModel.</param>
		static partial void CustomizeBackendConfiguration(ref BackendConfiguration config);
		
	}
	
	public interface IEntitiesModelUnitOfWork : IUnitOfWork
	{
		IQueryable<Address> Addresses
		{
			get;
		}
		IQueryable<CustomerAddress> CustomerAddresses
		{
			get;
		}
		IQueryable<SupplierAddress> SupplierAddresses
		{
			get;
		}
		IQueryable<Customer> Customers
		{
			get;
		}
		IQueryable<Supplier> Suppliers
		{
			get;
		}
	}
}
#pragma warning restore 1591
